# API Reference

This page uses `mkdocstrings` to generate an API reference from the `src/filoma` package.

::: filoma

## Package overview

The top-level package docstring is rendered above. Below are some focused sections for important modules and classes.

## DataFrame wrapper

The `filoma.DataFrame` wrapper provides convenience enrichers and helpers that operate on a Polars DataFrame internally.

::: filoma.dataframe.DataFrame
	handler: python

## Directory profiler

The directory profiling API and configuration helpers.

::: filoma.directories.directory_profiler
	handler: python
